@@ -202,6 +202,11 @@ class Unnest(Expression):
     arg_types = {'expressions': True, 'ordinality': False, 'table': False, 'columns': False}
 
 
+class Update(Expression):
+    token_type = TokenType.UPDATE
+    arg_types = {'this': True, 'expressions': True, 'where': False}
+
+
 class Values(Expression):
     token_type = TokenType.VALUES
     arg_types = {'expressions': True}
@@ -450,6 +455,10 @@ class DateStrToDate(Func):
     pass
 
 
+class Day(Func):
+    pass
+
+
 class If(Func):
     arg_types = {'this': True, 'true': True, 'false': False}
 
@@ -467,6 +476,10 @@ class Map(Func):
     arg_types = {'keys': True, 'values': True}
 
 
+class Month(Func):
+    pass
+
+
 class RegexLike(Func):
     token_type = TokenType.RLIKE
     arg_types = {'this': True, 'expression': True}
@@ -516,6 +529,10 @@ class TsOrDsToDateStr(Func):
     pass
 
 
+class TsOrDsToDate(Func):
+    pass
+
+
 class UnixToStr(Func):
     arg_types = {'this': True, 'format': True}
 
