@@ -39,8 +39,10 @@ class Generator:
         exp.DateAdd: lambda self, e: f"DATE_ADD({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.DateDiff: lambda self, e: f"DATE_DIFF({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.DateStrToDate: lambda self, e: f"DATE_STR_TO_DATE({self.sql(e, 'this')})",
+        exp.Day: lambda self, e: f"DAY({self.sql(e, 'this')})",
         exp.Initcap: lambda self, e: f"INITCAP({self.sql(e, 'this')})",
         exp.JSONPath: lambda self, e: f"JSON_PATH({self.sql(e, 'this')}, {self.sql(e, 'path')})",
+        exp.Month: lambda self, e: f"MONTH({self.sql(e, 'this')})",
         exp.StrPosition: lambda self, e: f"STR_POSITION({csv(self.sql(e, 'this'), self.sql(e, 'substr'), self.sql(e, 'position'))})",
         exp.StrToTime: lambda self, e: f"STR_TO_TIME({self.sql(e, 'this')}, {self.sql(e, 'format')})",
         exp.StrToUnix: lambda self, e: f"STR_TO_UNIX({self.sql(e, 'this')}, {self.sql(e, 'format')})",
@@ -52,6 +54,7 @@ class Generator:
         exp.TimeToTimeStr: lambda self, e: f"TIME_TO_TIME_STR({self.sql(e, 'this')})",
         exp.TimeToUnix: lambda self, e: f"TIME_TO_UNIX({self.sql(e, 'this')})",
         exp.TsOrDsToDateStr: lambda self, e: f"TS_OR_DS_TO_DATE_STR({self.sql(e, 'this')})",
+        exp.TsOrDsToDate: lambda self, e: f"TS_OR_DS_TO_DATE({self.sql(e, 'this')})",
         exp.UnixToStr: lambda self, e: f"UNIX_TO_STR({self.sql(e, 'this')}, {self.sql(e, 'format')})",
         exp.UnixToTime: lambda self, e: f"UNIX_TO_TIME({self.sql(e, 'this')})",
         exp.UnixToTimeStr: lambda self, e: f"UNIX_TO_TIME_STR({self.sql(e, 'this')})",
@@ -209,6 +212,12 @@ class Generator:
     def tuple_sql(self, expression):
         return f"({self.expressions(expression, flat=True)})"
 
+    def update_sql(self, expression):
+        this = self.sql(expression, 'this')
+        set_sql = self.expressions(expression)
+        where_sql = self.sql(expression.args.get('where'))
+        return f"UPDATE {this} SET {set_sql}{where_sql}"
+
     def values_sql(self, expression):
         return f"VALUES{self.seg('')}{self.expressions(expression)}"
 
