@@ -28,9 +28,11 @@ class Parser:
         'DATE_ADD': lambda args: exp.DateAdd(this=args[0], expression=args[1]),
         'DATE_DIFF': lambda args: exp.DateDiff(this=args[0], expression=args[1]),
         'DATE_STR_TO_DATE': lambda args: exp.DateStrToDate(this=args[0]),
+        'DAY': lambda args: exp.Day(this=args[0]),
         'IF': lambda args: exp.If(this=args[0], true=args[1], false=list_get(args, 2)),
         'INITCAP': lambda args: exp.Initcap(this=args[0]),
         'JSON_PATH': lambda args: exp.JSONPath(this=args[0], path=args[1]),
+        'MONTH': lambda args: exp.Month(this=args[0]),
         'STR_POSITION': lambda args: exp.StrPosition(this=args[0], substr=args[1], position=list_get(args, 2)),
         'STR_TO_TIME': lambda args: exp.StrToTime(this=args[0], format=args[1]),
         'STR_TO_UNIX': lambda args: exp.StrToUnix(this=args[0], format=args[1]),
@@ -42,6 +44,7 @@ class Parser:
         'TIME_TO_TIME_STR': lambda args: exp.TimeToTimeStr(this=args[0]),
         'TIME_TO_UNIX': lambda args: exp.TimeToUnix(this=args[0]),
         'TS_OR_DS_TO_DATE_STR': lambda args: exp.TsOrDsToDateStr(this=args[0]),
+        'TS_OR_DS_TO_DATE': lambda args: exp.TsOrDsToDate(this=args[0]),
         'UNIX_TO_STR': lambda args: exp.UnixToStr(this=args[0], format=args[1]),
         'UNIX_TO_TIME': lambda args: exp.UnixToTime(this=args[0]),
         'UNIX_TO_TIME_STR': lambda args: exp.UnixToTimeStr(this=args[0]),
@@ -240,6 +243,9 @@ class Parser:
         if self._match(TokenType.INSERT):
             return self._parse_insert()
 
+        if self._match(TokenType.UPDATE):
+            return self._parse_update()
+
         cte = self._parse_cte()
 
         if cte:
@@ -327,6 +333,13 @@ class Parser:
             overwrite=overwrite,
         )
 
+    def _parse_update(self):
+        return exp.Update(
+            this=self._parse_table(None),
+            expressions=self._match(TokenType.SET) and self._parse_csv(self._parse_equality),
+            where=self._parse_where(),
+        )
+
     def _parse_values(self):
         if not self._match(TokenType.VALUES):
             return None
